@@ -1,4 +1,4 @@
-// $Id: MiscControlPage.cpp,v 1.47 2006/07/08 12:45:15 mthuurne Exp $
+// $Id: MiscControlPage.cpp,v 1.49 2007/03/01 20:18:48 manuelbi Exp $
 // MiscControlPage.cpp: implementation of the MiscControlPage class.
 //
 //////////////////////////////////////////////////////////////////////
@@ -99,6 +99,8 @@ MiscControlPage::MiscControlPage(wxWindow * parent, openMSXController * controll
 	box->Append(wxT("--empty--"));
 	box->Append(wxT("logger"));
 	box->Append(wxT("simpl"));
+	box->Append(wxT("msx-printer"));
+	box->Append(wxT("epson-printer"));
 
 	/* This doesn't do anything, because it is "disabled" according to a comment in ConfigurationData
 	wxString filename;
@@ -123,7 +125,7 @@ MiscControlPage::~MiscControlPage()
 {
 }
 
-void MiscControlPage::FillInitialJoystickPortValues (int number_of_keyjoys)
+void MiscControlPage::FillInitialJoystickPortValues ()
 {
 //  temporary hardcoded joystick port devices (not for BSD)
 	wxString current;
@@ -144,14 +146,8 @@ void MiscControlPage::FillInitialJoystickPortValues (int number_of_keyjoys)
 		box[i]->Append(wxT("joynet"));
 		box[i]->Append(wxT("tetris2-protection"));
 		box[i]->Append(wxT("magic-key"));
-		if (number_of_keyjoys == 1){
-			box[i]->Append(wxT("keyjoystick"));
-		}
-		else{
-			box[i]->Append(wxT("keyjoystick1"));
-			box[i]->Append(wxT("keyjoystick2"));
-		}
-
+		box[i]->Append(wxT("keyjoystick1"));
+		box[i]->Append(wxT("keyjoystick2"));
 
 #ifndef __BSD__
 		for (int j=1;j<=joy.GetNumberJoysticks();j++) {
